@@ -38,8 +38,11 @@
 #include <glib.h>
 
 #include "irqbalance.h"
+#include "thermal.h"
 
+#ifdef HAVE_IRQBALANCEUI
 extern char *banned_cpumask_from_ui;
+#endif
 extern char *cpu_ban_string;
 
 GList *cpus;
@@ -113,12 +116,14 @@ static void setup_banned_cpus(void)
 	cpumask_t isolated_cpus;
 	char *env = NULL;
 
+#ifdef HAVE_IRQBALANCEUI
 	/* A manually specified cpumask overrides auto-detection. */
 	if (cpu_ban_string != NULL && banned_cpumask_from_ui != NULL) {
 		cpulist_parse(banned_cpumask_from_ui,
 			strlen(banned_cpumask_from_ui), banned_cpus);
 		goto out;
 	}
+#endif
 
 	/*
 	 * Notes:
@@ -154,10 +159,15 @@ static void setup_banned_cpus(void)
 	cpus_or(banned_cpus, nohz_full, isolated_cpus);
 
 	cpumask_scnprintf(buffer, 4096, isolated_cpus);
-	log(TO_CONSOLE, LOG_INFO, "Isolated CPUs: %s\n", buffer);
+	log(TO_CONSOLE, LOG_INFO, "Prevent irq assignment to these isolated CPUs: %s\n", buffer);
 	cpumask_scnprintf(buffer, 4096, nohz_full);
-	log(TO_CONSOLE, LOG_INFO, "Adaptive-ticks CPUs: %s\n", buffer);
+	log(TO_CONSOLE, LOG_INFO, "Prevent irq assignment to these adaptive-ticks CPUs: %s\n", buffer);
 out:
+#ifdef HAVE_THERMAL
+	cpus_or(banned_cpus, banned_cpus, thermal_banned_cpus);
+	cpumask_scnprintf(buffer, 4096, thermal_banned_cpus);
+	log(TO_CONSOLE, LOG_INFO, "Prevent irq assignment to these thermal-banned CPUs: %s\n", buffer);
+#endif
 	cpumask_scnprintf(buffer, 4096, banned_cpus);
 	log(TO_CONSOLE, LOG_INFO, "Banned CPUs: %s\n", buffer);
 }
@@ -305,7 +315,7 @@ static void do_one_cpu(char *path)
 
 	cpu->obj_type = OBJ_TYPE_CPU;
 
-	cpu->number = strtoul(&path[27], NULL, 10);
+	cpu->number = cpunr;
 
 	cpu_set(cpu->number, cpu_online_map);
 	
